<?php
/*
 * CloudConvert API Class
/*==========================*\
# Clone Coded by P30vel.ir   #

\*==========================*/

class CloudConvert
{

    const TIMEOUT = 180;
    private $apikey;
    private $url;

    public function __construct($inputformat, $outputformat, $apikey = null)
    {
        $this->apikey = $apikey;
        $data         = $this->req('https://api.cloudconvert.org/process', array(
            'inputformat' => $inputformat,
            'outputformat' => $outputformat,
            'apikey' => $apikey
        ));
        if ($data === false)
            return false;
        if (strpos($data->url, 'http') === false)
            $data->url = "https:" . $data->url;
        $this->url = $data->url;
    }
    /*
     * Does the actual conversion (server side)
     */
    public function convert($filepath, $outputformat, $target)
    {
        $file = pathinfo($filepath);
        $this->req($this->url, array(
            'input' => 'upload',
            'format' => $outputformat,
            'file' => '@' . $filepath
        ));
        $time = 0;
        /*
         * Check the status every second, up to timeout
         */
        while ($time <= self::TIMEOUT) {
            sleep(1);
            $time++;
            if ($this->req($this->url) === false)
                return false;
            $this->data = $this->req($this->url);
            if ($this->data->step == 'error') {
                throw new Exception($this->data->message);
                return false;
            } elseif ($this->data->step == 'finished' && isset($this->data->output) && isset($this->data->output->url)) {
                if (strpos($this->data->output->url, 'http') === false) {
                    $this->data->output->url = "https:" . $this->data->output->url;
                }
                return true;
            }
        }
        throw new Exception('Timeout');
        return false;
    }
    public function getURL()
    {
        return $this->url;
    }
    private function req($url, $post = null)
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FAILONERROR, false);

        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        if (!empty($post)) {
            curl_setopt($ch, CURLOPT_POST, TRUE);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
        }
        $return = curl_exec($ch);
        if ($return === FALSE) {
            return false;
        } else {
            $json = json_decode($return);
            if (isset($json->error)) {
                $this->error = $json->error;
                return false;
            }
            return $json;
        }
        curl_close($ch);
    }
}
?>